@@ -3,7 +3,7 @@ context("authentication")
 test_that("session validation works appropriately", {
   expect_false(session_validate(5))
 	#expect_null(current_session())
-	session <- httr::handle("http://google.com")
+	session <- httr::handle("https://google.com")
 	attributes(session) <- c(attributes(session), list(birthdate=Sys.time()))
 	expect_true(session_validate(session))
 	set_expiration(as.difftime("00:00:01"))
